handler

package
v1.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

const DefaultProxy = "http://localhost:7890"

Variables

This section is empty.

Functions

func CheckGithubAccess

func CheckGithubAccess(proxy string) bool

检查能否访问 github.com

func DownloadDocs

func DownloadDocs(repoURL, outputDir, docsPath, proxy string)

DownloadDocs downloads txt and md files from a GitHub repository

func DownloadDocsToDataDir

func DownloadDocsToDataDir(repoURL, docsPath, proxy, docsBaseDir string)

DownloadDocsToDataDir downloads txt and md files from a GitHub repository to the data directory structure

func DownloadRepo

func DownloadRepo(url string, proxy string, opts ...common.Option)

func DownloadRepoToDataDir

func DownloadRepoToDataDir(url, proxy string)

DownloadRepoToDataDir downloads a repository to the data directory structure

func DownloadRepos

func DownloadRepos(repos []string, proxy string)

func ReadFromFile

func ReadFromFile(file string) (urlList []string)

func Repo

func Repo(hub *common.DownHub)

func SetConfig

func SetConfig(c *config.Config)

SetConfig sets the configuration for the handler

Types

This section is empty.

Jump to