Documentation
¶
Index ¶
- Constants
- func CheckGithubAccess(proxy string) bool
- func DownloadDocs(repoURL, outputDir, docsPath, proxy string)
- func DownloadDocsToDataDir(repoURL, docsPath, proxy, docsBaseDir string)
- func DownloadRepo(url string, proxy string, opts ...common.Option)
- func DownloadRepoToDataDir(url, proxy string)
- func DownloadRepos(repos []string, proxy string)
- func ReadFromFile(file string) (urlList []string)
- func Repo(hub *common.DownHub)
- func SetConfig(c *config.Config)
Constants ¶
const DefaultProxy = "http://localhost:7890"
Variables ¶
This section is empty.
Functions ¶
func DownloadDocs ¶
func DownloadDocs(repoURL, outputDir, docsPath, proxy string)
DownloadDocs downloads txt and md files from a GitHub repository
func DownloadDocsToDataDir ¶
func DownloadDocsToDataDir(repoURL, docsPath, proxy, docsBaseDir string)
DownloadDocsToDataDir downloads txt and md files from a GitHub repository to the data directory structure
func DownloadRepoToDataDir ¶
func DownloadRepoToDataDir(url, proxy string)
DownloadRepoToDataDir downloads a repository to the data directory structure
func DownloadRepos ¶
func ReadFromFile ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.